@@ -5,18 +5,18 @@ import pathlib
 import random
 import shutil
 import textwrap
-from typing import Any, Optional, Protocol
+from typing import TYPE_CHECKING, Any, Optional, Protocol
 
 import pytest
 
-from _pytest.doctest import DoctestItem
-from _pytest.fixtures import SubRequest
-
 from libvcs._internal.run import run
 from libvcs.sync.git import GitRemote, GitSync
 from libvcs.sync.hg import HgSync
 from libvcs.sync.svn import SvnSync
 
+if TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
 skip_if_git_missing = pytest.mark.skipif(
     not shutil.which("git"), reason="git is not available"
 )
@@ -184,6 +184,9 @@ def unique_repo_name(remote_repos_path: pathlib.Path, max_retries: int = 15) ->
         return remote_repo_name
 
 
+InitCmdArgs: "TypeAlias" = Optional[list[str]]
+
+
 class CreateProjectCallbackProtocol(Protocol):
     def __call__(self, remote_repo_path: pathlib.Path) -> None:
         ...
@@ -195,6 +198,7 @@ class CreateProjectCallbackFixtureProtocol(Protocol):
         remote_repos_path: pathlib.Path = ...,
         remote_repo_name: Optional[str] = ...,
         remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = ...,
+        init_cmd_args: InitCmdArgs = ...,
     ) -> pathlib.Path:
         ...
 
@@ -203,9 +207,12 @@ def _create_git_remote_repo(
     remote_repos_path: pathlib.Path,
     remote_repo_name: str,
     remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+    init_cmd_args: InitCmdArgs = ["--bare"],
 ) -> pathlib.Path:
+    if init_cmd_args is None:
+        init_cmd_args = []
     remote_repo_path = remote_repos_path / remote_repo_name
-    run(["git", "init", remote_repo_name], cwd=remote_repos_path)
+    run(["git", "init", remote_repo_name, *init_cmd_args], cwd=remote_repos_path)
 
     if remote_repo_post_init is not None and callable(remote_repo_post_init):
         remote_repo_post_init(remote_repo_path=remote_repo_path)
@@ -224,6 +231,7 @@ def create_git_remote_repo(
         remote_repos_path: pathlib.Path = remote_repos_path,
         remote_repo_name: Optional[str] = None,
         remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+        init_cmd_args: InitCmdArgs = ["--bare"],
     ) -> pathlib.Path:
         return _create_git_remote_repo(
             remote_repos_path=remote_repos_path,
@@ -231,6 +239,7 @@ def create_git_remote_repo(
             if remote_repo_name is not None
             else unique_repo_name(remote_repos_path=remote_repos_path),
             remote_repo_post_init=remote_repo_post_init,
+            init_cmd_args=init_cmd_args,
         )
 
     return fn
@@ -252,6 +261,7 @@ def git_remote_repo(remote_repos_path: pathlib.Path) -> pathlib.Path:
         remote_repos_path=remote_repos_path,
         remote_repo_name="dummyrepo",
         remote_repo_post_init=git_remote_repo_single_commit_post_init,
+        init_cmd_args=None,  # Don't do --bare
     )
 
 
@@ -259,11 +269,14 @@ def _create_svn_remote_repo(
     remote_repos_path: pathlib.Path,
     remote_repo_name: str,
     remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+    init_cmd_args: InitCmdArgs = None,
 ) -> pathlib.Path:
     """Create a test SVN repo to for checkout / commit purposes"""
+    if init_cmd_args is None:
+        init_cmd_args = []
 
     remote_repo_path = remote_repos_path / remote_repo_name
-    run(["svnadmin", "create", remote_repo_path])
+    run(["svnadmin", "create", remote_repo_path, *init_cmd_args])
 
     if remote_repo_post_init is not None and callable(remote_repo_post_init):
         remote_repo_post_init(remote_repo_path=remote_repo_path)
@@ -282,6 +295,7 @@ def create_svn_remote_repo(
         remote_repos_path: pathlib.Path = remote_repos_path,
         remote_repo_name: Optional[str] = None,
         remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+        init_cmd_args: InitCmdArgs = None,
     ) -> pathlib.Path:
         return _create_svn_remote_repo(
             remote_repos_path=remote_repos_path,
@@ -289,6 +303,7 @@ def create_svn_remote_repo(
             if remote_repo_name is not None
             else unique_repo_name(remote_repos_path=remote_repos_path),
             remote_repo_post_init=remote_repo_post_init,
+            init_cmd_args=init_cmd_args,
         )
 
     return fn
@@ -312,10 +327,14 @@ def _create_hg_remote_repo(
     remote_repos_path: pathlib.Path,
     remote_repo_name: str,
     remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+    init_cmd_args: InitCmdArgs = None,
 ) -> pathlib.Path:
     """Create a test hg repo to for checkout / commit purposes"""
+    if init_cmd_args is None:
+        init_cmd_args = []
+
     remote_repo_path = remote_repos_path / remote_repo_name
-    run(["hg", "init", remote_repo_name], cwd=remote_repos_path)
+    run(["hg", "init", remote_repo_name, *init_cmd_args], cwd=remote_repos_path)
 
     if remote_repo_post_init is not None and callable(remote_repo_post_init):
         remote_repo_post_init(remote_repo_path=remote_repo_path)
@@ -343,6 +362,7 @@ def create_hg_remote_repo(
         remote_repos_path: pathlib.Path = remote_repos_path,
         remote_repo_name: Optional[str] = None,
         remote_repo_post_init: Optional[CreateProjectCallbackProtocol] = None,
+        init_cmd_args: InitCmdArgs = None,
     ) -> pathlib.Path:
         return _create_hg_remote_repo(
             remote_repos_path=remote_repos_path,
@@ -350,6 +370,7 @@ def create_hg_remote_repo(
             if remote_repo_name is not None
             else unique_repo_name(remote_repos_path=remote_repos_path),
             remote_repo_post_init=remote_repo_post_init,
+            init_cmd_args=init_cmd_args,
         )
 
     return fn
@@ -410,7 +431,7 @@ def svn_repo(projects_path: pathlib.Path, svn_remote_repo: pathlib.Path) -> SvnS
 
 @pytest.fixture
 def add_doctest_fixtures(
-    request: SubRequest,
+    request: pytest.FixtureRequest,
     doctest_namespace: dict[str, Any],
     tmp_path: pathlib.Path,
     set_home: pathlib.Path,
@@ -420,6 +441,8 @@ def add_doctest_fixtures(
     create_hg_remote_repo: CreateProjectCallbackFixtureProtocol,
     git_repo: pathlib.Path,
 ) -> None:
+    from _pytest.doctest import DoctestItem
+
     if not isinstance(request._pyfuncitem, DoctestItem):  # Only run on doctest items
         return
     doctest_namespace["tmp_path"] = tmp_path
@@ -428,6 +451,7 @@ def add_doctest_fixtures(
         doctest_namespace["create_git_remote_repo"] = functools.partial(
             create_git_remote_repo,
             remote_repo_post_init=git_remote_repo_single_commit_post_init,
+            init_cmd_args=None,
         )
         doctest_namespace["create_git_remote_repo_bare"] = create_git_remote_repo
         doctest_namespace["git_local_clone"] = git_repo
